#!/usr/bin/env node

/**
 * Amaze testing suite
 * v.0.2.8
 *
 * https://npmjs.org/package/amaze-tdd
 */

'use strict';

const Mocha = require('../node_modules/mocha');
const webdriver = require('../node_modules/selenium-webdriver');
const chromedriver = require('../node_modules/chromedriver');
const path = require('path');
const fs = require('fs');
const glob = require('glob');

const driverDir = path.join(__dirname, '../');

var flags = process.argv;
var chrome;
var client;
var options;
var mocha;
var Amaze;

if (flags.indexOf('phantomjs') > -1) {
    client = new webdriver.Builder().forBrowser('phantomjs');
} else {
    chrome = require('../node_modules/selenium-webdriver/chrome');
    options = new chrome.Options();
    options.addExtensions(driverDir + '/selenium/crx/5.1.1_0.crx');
    client = new webdriver.Builder().forBrowser('chrome').setChromeOptions(options);
}

mocha = new Mocha({
    ui: 'tdd',
    reporter: 'spec',
    timeout: 30000
});

Amaze = {
    Webdriver: webdriver,
    Client: client,
    By: webdriver.By,
    Until: webdriver.until,
    Chrome: chromedriver,
    Mocha: mocha,
    Expect: require('chai').expect,
    Assert: require('chai').assert,
    $: require('selenium-query')
};

function isDemo(file) {
    let parts = file.split('/');
    for (let i = 0; i < parts.length; i++) {
        if (parts.indexOf('demo-spec.js') > -1) {
            return file;
        }
    }
}

function isNotDemo(file) {
    let parts = file.split('/');
    for (let i = 0; i < parts.length; i++) {
        if (parts.indexOf('demo-spec.js') < 0) {
            return file;
        }
    }
}

glob('./**/*-spec.js', function(err, files) {
    if (err) return console.log(err);

    if (flags.indexOf('sanity-check') > -1) {
        let only = files.filter(isDemo);
        for (let i = 0; i < only.length; i++) {
            Amaze.Mocha.addFile(only[i]);
        }
    } else {
        let only = files.filter(isNotDemo);
        for (let i = 0; i < only.length; i++) {
            Amaze.Mocha.addFile(only[i]);
        }

        if (fs.statSync(process.cwd() + '/.amazerc')) {
            Amaze.Configs = require(process.cwd() + '/.amazerc');
        }
    }

    if (Amaze.Mocha.files.length > 0) {
        Amaze.Mocha.run();
    } else {
        try {
            throw new Error('No tests to run.\n');
            return false;
        } catch (e) {
            return console.log(e.name + ': ' + e.message);
        }
    }
});

module.exports = Amaze;