'use strict';

var Amaze = require('../');
var Browser;

suite('Sanity check: perform a Google search', function() {

    suiteSetup(function() {
        Browser = Amaze.Client.build();
    });

    test('it can navigate to the Google search homepage', function() {
        return Browser.get('https://google.com');
    });

    test('it has the correct title', function() {
        return Browser.getTitle().then(function(title) {
            Amaze.Expect(title).to.equal('Google');
        });
    });

    test('it can find the search box', function() {
        return Amaze.$(Browser).find('input[name="q"]').then(function(search) {
            Amaze.Expect(search).to.have.length.above(0);
        });
    });

    test('it can perform a search', function() {
        return Browser.get('https://google.com?noj=1').then(function() {
            return Amaze.$(Browser).find('input[name="q"]').then(function(search) {
                return Amaze.$(search).val('Deque accessibility').then(function() {
                    search.sendKeys(Amaze.Webdriver.Key.ENTER);
                    return Browser.getTitle().then(function(title) {
                        Amaze.Expect(title).to.equal('Deque accessibility - Google Search');
                    });
                });
            });
        });
    });

    suiteTeardown(function(done) {
        Browser.quit().then(done);
    });
});